package com.jusfoun.ydylsz.controller;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import com.jusfoun.ydylsz.pojo.SysResource;
import com.jusfoun.ydylsz.service.KshFileUploadService;
import com.jusfoun.ydylsz.tool.PathTool;
import com.jusfoun.ydylsz.vo.out.base.RootResult;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;

@Api(description = "文件上传接口")
@Controller
@RequestMapping(value = "/kshFileUpload")
@CrossOrigin
public class KshFileUploadController {
	
	@Autowired
	private KshFileUploadService kshFileUploadService;

	private static Logger log = LoggerFactory.getLogger(KshFileUploadController.class);
	
	/**
	 * 文件上传（单个或多个） 前端文件名：resFile
	 * 
	 * @param request
	 * @return
	 */
	@ApiOperation(value = "上传", notes = "上传")
	@RequestMapping(value = "/fileUpload", method = RequestMethod.POST)
	public @ResponseBody RootResult<List<SysResource>> batchUpload(@RequestParam MultipartFile[] file,
			HttpServletRequest request) {
		String uploadPath = PathTool.makeRealWebpicPath(request, null, new Date());
		RootResult<List<SysResource>> r = new RootResult<List<SysResource>>();
		Integer imgWidth = Integer.valueOf(
				StringUtils.isBlank(request.getParameter("imgWidth")) ? "100" : request.getParameter("imgWidth"));
		Integer imgHeight = Integer.valueOf(
				StringUtils.isBlank(request.getParameter("imgHeight")) ? "100" : request.getParameter("imgHeight"));
		List<SysResource> resList = new ArrayList<SysResource>();
		for (MultipartFile resFile : file) {
			resList.add(kshFileUploadService.uploadFile(request, new Date(), uploadPath, resFile, imgWidth, imgHeight));
		}
		r.setData(resList);
		return r;
	}
	
	
	@ApiOperation(value = "上传图片或视频", notes = "参数：图片对象或视频")
    @RequestMapping(value = "/upload",method = RequestMethod.POST, consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
	@ResponseBody
    public RootResult<SysResource> upload(@RequestBody MultipartFile file,HttpServletRequest request) {
		RootResult<SysResource> r = new RootResult<SysResource>();
        try {
        	String uploadPath = PathTool.makeRealWebpicPath(request, null, new Date());
        	Integer imgWidth = Integer.valueOf(
    				StringUtils.isBlank(request.getParameter("imgWidth")) ? "100" : request.getParameter("imgWidth"));
    		Integer imgHeight = Integer.valueOf(
    				StringUtils.isBlank(request.getParameter("imgHeight")) ? "100" : request.getParameter("imgHeight"));
    		SysResource res = kshFileUploadService.executeUpload(request, new Date(), uploadPath, file, imgWidth, imgHeight);
    		r.setData(res);
        } catch (Exception e) {
            log.error( "保存对象，发生异常", e.getMessage() );
        }
		return r;
    }
	
}
