package com.jusfoun.ydylsz.controller;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import com.jusfoun.ydylsz.pojo.KshHlhtKuquInfo;
import com.jusfoun.ydylsz.pojo.KshHlhtXzqh;
import com.jusfoun.ydylsz.service.KshHlhtNktService;
import com.jusfoun.ydylsz.service.KshHlhtSbxxService;
import com.jusfoun.ydylsz.util.PageUtils;
import com.jusfoun.ydylsz.vo.in.KshHlhtSbxxInputVo;
import com.jusfoun.ydylsz.vo.out.base.RootResult;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@Api(description="鸟瞰图接口")
@Controller
@RequestMapping(value = "/kshHlhtNkt")
@CrossOrigin
public class KshHlhtNktController {

	private static Logger log = LoggerFactory.getLogger(KshHlhtNktController.class);
	
	@Autowired
	private KshHlhtNktService kshHlhtNktService;
	
	@Autowired
	private KshHlhtSbxxService kshHlhtSbxxService;
	
	@ApiOperation(value="分页列表展示", notes="分页列表展示")
    @RequestMapping(value = "/selectList",method = RequestMethod.POST)
	@ResponseBody
	public RootResult<Object> selectList(@ModelAttribute KshHlhtSbxxInputVo vo,HttpServletRequest req) {
		RootResult<Object> r = new RootResult<Object>();
		try {
			vo.setPageNum((vo.getPageNum() - 1) * vo.getPageSize());
			// 110000 是系统管理员得用户id
			if(vo.getUserId() == 120000) {
				vo.setUserId(null);
			}			
			//查询总记录数
			Long total = kshHlhtNktService.queryTotalCount(vo);
			//分页结果集
			List<KshHlhtKuquInfo> data = kshHlhtNktService.queryList(vo,req);
			//分页工具类
			PageUtils<KshHlhtKuquInfo> pageInfo  = new PageUtils<KshHlhtKuquInfo>();
			//填充数据
			pageInfo.setTotal(total);
			pageInfo.setList(data);
			r.setData(pageInfo);
		}catch (Exception e) {
			r.failure("分页列表异常");
			log.error("分页列表异常", e);
			e.printStackTrace();
		}
		return r;
	}
	
	@ApiOperation(value = "库区信息保存", notes="库区信息保存")
	@RequestMapping(value = "/saveKuquInfo", method = RequestMethod.POST)
	@ResponseBody
	public RootResult<Object> saveKuquInfo(@ModelAttribute KshHlhtKuquInfo info) {
		RootResult<Object> r = new RootResult<Object>();
		try {
			info.setNkt("已上传");
			kshHlhtSbxxService.saveKuquInfo(info);
		} catch (Exception e) {
			log.error("库区信息保存异常", e);
			r.failure("库区信息保存异常");
			e.printStackTrace();
		}
		return r;
	}
	
	@ApiOperation(value = "审核", notes="审核")
	@RequestMapping(value = "/checkKuquInfo", method = RequestMethod.POST)
	@ResponseBody
	public RootResult<Object> checkKuquInfo(Integer id,String zt) {
		RootResult<Object> r = new RootResult<Object>();
		try {
			kshHlhtNktService.checkKuquInfo(id,zt);
		} catch (Exception e) {
			log.error("审核异常", e);
			r.failure("审核异常");
			e.printStackTrace();
		}
		return r;
	}
	
	@ApiOperation(value = "修改", notes="修改")
	@RequestMapping(value = "/updateKuquInfo", method = RequestMethod.POST)
	@ResponseBody
	public RootResult<Object> updateKuquInfo(@ModelAttribute KshHlhtKuquInfo info) {
		RootResult<Object> r = new RootResult<Object>();
		try {
			kshHlhtNktService.updateKuquInfo(info);
		} catch (Exception e) {
			log.error("修改异常", e);
			r.failure("修改异常");
			e.printStackTrace();
		}
		return r;
	}
	
	@ApiOperation(value = "详情", notes="详情")
	@RequestMapping(value = "/viewTuPian", method = RequestMethod.POST)
	@ResponseBody
	public RootResult<Object> viewTuPian(Integer id,HttpServletRequest request) {
		RootResult<Object> r = new RootResult<Object>();
		try {
			KshHlhtKuquInfo xzqh = kshHlhtNktService.viewTuPian(id,request);
			r.setData(xzqh);
		} catch (Exception e) {
			log.error("图片预览异常", e);
			r.failure("图片预览异常");
			e.printStackTrace();
		}
		return r;
	}
	
	@ApiOperation(value = "模糊库区信息", notes="模糊库区信息")
	@RequestMapping(value = "/queryKqxxInfo", method = RequestMethod.POST)
	@ResponseBody
	public RootResult<Object> queryKqxxInfo(String kqmc) {
		RootResult<Object> r = new RootResult<Object>();
		try {
			List<KshHlhtKuquInfo> kqxx = kshHlhtNktService.queryKqxxInfo(kqmc);
			r.setData(kqxx);
		} catch (Exception e) {
			log.error("模糊库区信息异常", e);
			r.failure("模糊库区信息异常");
			e.printStackTrace();
		}
		return r;
	}
	@ApiOperation(value = "通过kqdm查询图片id", notes="模糊库区信息")
	@RequestMapping(value = "/queryResIdByKqdm", method = RequestMethod.POST)
	@ResponseBody
	public RootResult<Object> queryResIdByKqdm(String kqdm) {
		RootResult<Object> r = new RootResult<Object>();
		try {
			String kqxx = kshHlhtNktService.queryResIdByKqdm(kqdm);;
			r.setData(kqxx);
		} catch (Exception e) {
			log.error("通过kqdm查询图片id异常", e);
			r.failure("通过kqdm查询图片id异常");
			e.printStackTrace();
		}
		return r;
	}
}
