package com.jusfoun.ydylsz.controller;
import java.text.SimpleDateFormat;
import java.util.*;

import com.hikvision.artemis.sdk.ArtemisHttpUtil;
import com.hikvision.artemis.sdk.config.ArtemisConfig;
import com.jusfoun.ydylsz.pojo.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.jusfoun.ydylsz.service.KshHlhtSbxxService;
import com.jusfoun.ydylsz.service.KshHlhtZzjgService;
import com.jusfoun.ydylsz.util.MenuTreeUtil;
import com.jusfoun.ydylsz.vo.in.KshHlhtScfzInVo;
import com.jusfoun.ydylsz.vo.out.base.RootResult;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@Api(description="组织结构接口")
@Controller
@RequestMapping(value = "/kshHlhtZzjg")
@CrossOrigin
public class KshHlhtZzjgController {
	
	@Autowired
    private KshHlhtZzjgService kshHlhtZzjgService;
	
	@Autowired
	private KshHlhtSbxxService kshHlhtSbxxService;
	
	private static Logger log = LoggerFactory.getLogger(KshHlhtZzjgController.class);
	
	@ApiOperation(value="自定义查询", notes="自定义查询")
    @RequestMapping(value = "/queryList",method = RequestMethod.POST)
	@ResponseBody
	public RootResult<Object> queryList(Integer yhid) {
		RootResult<Object> r = new RootResult<Object>();
		try {
			if(yhid == 110000) {
				yhid = null;
			}
			List<KshHlhtXzqh> dataList = kshHlhtZzjgService.queryList(yhid);
			r.setData(dataList);
		}catch (Exception e) {
			r.failure("自定义查询异常");
			log.error("自定义查询异常", e);
			e.printStackTrace();
		}
		return r;
	}
	
	@ApiOperation(value="组织机构数展示", notes="组织机构数展示")
    @RequestMapping(value = "/selectList",method = RequestMethod.POST)
	@ResponseBody
	public RootResult<Object> selectList(String yhid) {
		RootResult<Object> r = new RootResult<Object>();
		try {
			
//			List<TreeNode> resultList = new ArrayList<TreeNode>();
//			
//			// 查询父节点Id
//			List<TreeNode> nodeList = kshHlhtZzjgService.queryParentId(yhid);   // 0 这个父节点
//			for (TreeNode treeNode : nodeList) {
//				if(treeNode.getZid() != null) {
//					TreeNode node = getTree(treeNode);
//					if(node != null) {
//						resultList.add(node);
//					}
//				}
//			}
			// 获取到class_str_id 的值
			String classStrId = kshHlhtZzjgService.queryClassGovCode(yhid);
            List<TreeNode> list= kshHlhtZzjgService.queryTreeNodeList();
			MenuTreeUtil menuTree = new MenuTreeUtil();
			List<Object> menuList = menuTree.menuList(list, classStrId);
			r.setData(menuList);
			
		}catch (Exception e) {
			r.failure("分页列表异常");
			log.error("分页列表异常", e);
			e.printStackTrace();
		}
		return r;
	}
	
//	private TreeNode getTree(TreeNode treeNode) {
//		// 所有子类得数据
//		List<TreeNode> childList = kshHlhtZzjgService.queryChildListById(treeNode.getZid());
//		if(childList != null) {
//			treeNode.setChildren(childList);
//			for(TreeNode childNode : childList) {
//				if(childNode.getZid() != null) {
//					getTree(childNode);
//				}
//			}
//		}
//		return treeNode;
//	}
	
	@ApiOperation(value = "生成分组", notes="生成分组")
	@RequestMapping(value = "/insertKshHlhtScfz", method = RequestMethod.POST)
	@ResponseBody
	public RootResult<Object> insertKshHlhtScfz(@ModelAttribute KshHlhtScfzInVo vo){
		RootResult<Object> r = new RootResult<Object>();
		try {
			
			// 先插入到自定义表中
			SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
			
			vo.setCjsj(df.parse(df.format(new Date())));
			
			kshHlhtZzjgService.insertZdycx(vo);
			
			KshHlhtZzsbgl zzsb = new KshHlhtZzsbgl();
			// 将传过来得设备Id进行分割			
			String str[] = vo.getSbxxId().split(",");
			for(int i=0;i<str.length;i++) {
				String sbId = str[i];
				zzsb.setSbId(Integer.parseInt(sbId));
				zzsb.setZzjgId(vo.getId());
				kshHlhtZzjgService.insertZdysbgl(zzsb);
			}		
			
		} catch (Exception e) {
			log.error("生成分组异常", e);
			r.failure("生成分组异常");
			e.printStackTrace();
		}
		return r;
	}	
	
	@ApiOperation(value = "删除分组", notes="删除分组")
	@RequestMapping(value = "/deleteKshHlhtScfz", method = RequestMethod.POST)
	@ResponseBody
	public RootResult<Object> deleteKshHlhtScfz(String id){
		RootResult<Object> r = new RootResult<Object>();
		try {
			// 删除自定义表
			kshHlhtZzjgService.deleteKshHlhtMainScfz(id);
			// 删除自定义表关联 
			kshHlhtZzjgService.deleteKshHlhtSonScfz(id);
		}catch (Exception e) {
			log.error("删除分组异常", e);
			r.failure("删除分组异常");
			e.printStackTrace();
		}
		return r;
	}
	
	
	/*@ApiOperation(value = "手动同步(优化方法)", notes="手动同步(优化方法)")
    @RequestMapping(value = "/synchronizationHand", method = RequestMethod.POST)
    @ResponseBody
    public RootResult<Object> synchronizationHand(String zzjgId){
		RootResult<Object> r = new RootResult<Object>();
		try {
			
			kshHlhtZzjgService.deleteTemp();
	            
            //更新组织机构
            Integer pageNo = 1;
            Integer pageSize = 1;
            Map<String,Object> map = new HashMap<>();
            Map<String,Object> mapSb = new HashMap<>();
            String result = GetCameraPreviewURL(pageNo,pageSize,1);

            JSONObject jsonString = JSONObject.parseObject(result);

            JSONObject jsonData = jsonString.getJSONObject("data");

            Integer jsonTotal = jsonData.getInteger("total");   // 总条数

            List<TreeNode> treeNode = kshHlhtZzjgService.queryClassStrId(zzjgId);
            TreeNode treeNodes =  treeNode.get(0);

            System.out.println("组织机构总条数为----------" + jsonTotal +"----------------------");
            
            if(jsonTotal > 0) {
            	
            	Integer pageNum = jsonTotal / 1000 + 1;  // 判断循环几次

                for (int i = 1; i <= pageNum.intValue(); i++) {

                    String resultData = GetCameraPreviewURL(i, 1000, 1);

                    // 将String转化为json数据
                    JSONObject objData = JSONObject.parseObject(resultData);

                    JSONObject jsonObjData = objData.getJSONObject("data");

                    JSONArray arrayList = JSON.parseArray(jsonObjData.getString("list"));

                    Iterator<Object> it = arrayList.iterator();
                    while (it.hasNext()) {
                        JSONObject obj = (JSONObject) it.next();
                        NodeTemp nodeTemp = new NodeTemp();
                        if(obj.getString("parentIndexCode").length()>21) {
                        	nodeTemp.setFid(obj.getString("indexCode").substring(0,2));
                        }else {
                        	nodeTemp.setFid(obj.getString("parentIndexCode"));
                        }
                        if(obj.getString("indexCode").length()>21) {
                        	nodeTemp.setZid(zzjgId);
                        }else {
                        	nodeTemp.setZid(obj.getString("indexCode"));
                        }
                        nodeTemp.setName(obj.getString("name"));
                        nodeTemp.setLeaf(obj.getString("leaf"));
                        kshHlhtZzjgService.saveTemp(nodeTemp);
                    }
                }            	
            }
            
           //获取需要更新的数据
           List<NodeTemp> nodeTemps = null;
           
           if(treeNodes.getZid().length()==2) {
        	   nodeTemps = kshHlhtZzjgService.selectTempHead(treeNodes.getZid());
           }else {
        	   nodeTemps = kshHlhtZzjgService.selectTemp(treeNodes.getZid()); 
           }
           if(nodeTemps!=null&&nodeTemps.size()>0){
               for(NodeTemp nodeTemp:nodeTemps){
                   if("true".equals(nodeTemp.getLeaf())){
                       mapSb.put(nodeTemp.getZid(),nodeTemp.getZid());
                   }
                   map.put(nodeTemp.getZid(),nodeTemp.getZid());
               }
           }
         
         // 更新组织机构树
         if(jsonTotal > 0) {
        	 
        	 Integer pageNum = jsonTotal / 1000+1;  // 判断循环几次

             for (int i = 1; i <= pageNum.intValue(); i++) {

                 String resultData = GetCameraPreviewURL(i,1000,1);

                 // 将String转化为json数据
                 JSONObject objData = JSONObject.parseObject(resultData);

                 JSONObject jsonObjData = objData.getJSONObject("data");

                 JSONArray arrayList = JSON.parseArray(jsonObjData.getString("list"));

                 Iterator<Object> it = arrayList.iterator();
                 while (it.hasNext()) {

                     JSONObject obj = (JSONObject) it.next();

                     String name = obj.getString("name");

                     String parentId = obj.getString("parentIndexCode");  // 父节点

                     String indexCode = obj.getString("indexCode");

                     if(map.get(indexCode)==null){

                     }else{
                    	 
                    	 TreeNode treeNode1 = this.kshHlhtZzjgService.queryById(obj.getString("indexCode"));                    	 
                         if (treeNode1 != null){	 
                           treeNode1.setZzmc(name);
                           //treeNode1.setZid(indexCode);
                           //treeNode1.setFid(parentId);
                           this.kshHlhtZzjgService.updateKshHlhtScfz(treeNode1);
                           System.out.println("==================gengxin===================");
                         }else {
                        	 
                        	List<NodeTemp> nodeTemp = kshHlhtZzjgService.queryListTemp(obj.getString("indexCode"));
                  			KshHlhtScfzInVo invo = new KshHlhtScfzInVo();
                  			for (NodeTemp node : nodeTemp) {
                  				invo.setZzmc(node.getName());
                  				invo.setZId(node.getZid());
                  				invo.setFId(node.getFid());                 				
                  				if(node.getName().equals("国家粮食局")) {
                  					invo.setZzmc("国家粮食和物资储备局");
                  					invo.setIntzId(110000);
                  					invo.setIntfId(0);
                  				}else if(node.getFid().equals("root000000")){					
                  					invo.setIntzId(Integer.parseInt(node.getZid()));
                  					invo.setIntfId(110000);
                  				}else {
                  					if(node.getZid().length() == 20) {	
                  						if(node.getFid().length() == 20) {
                  							invo.setIntzId(Integer.parseInt(node.getZid().substring(0, 6) + node.getZid().substring(18, 20)));
                  							invo.setIntfId(Integer.parseInt(node.getFid().substring(0, 6) + node.getFid().substring(18, 20)));
                  						}else {
                  							invo.setIntzId(Integer.parseInt(node.getZid().substring(0, 6) + node.getZid().substring(18, 20)));
                  							invo.setIntfId(Integer.parseInt(node.getFid()));
                  						}						
                  					}else{
                  						if(node.getFid().length() == 20) {
                  							invo.setIntzId(Integer.parseInt(node.getZid()));
                  							invo.setIntfId(Integer.parseInt(node.getFid().substring(0, 6) + node.getFid().substring(18, 20)));
                  						}else {
                  							invo.setIntzId(Integer.parseInt(node.getZid()));
                  							invo.setIntfId(Integer.parseInt(node.getFid()));
                  						}						
                  					}
                  				}	
                  				kshHlhtZzjgService.insertClassZzjg(invo);
                  			} 
                           }   
                         }
                         map.put(indexCode,indexCode);
                     }
                 }
         } 
         
         System.out.println("================================组织机构更新完成====================================");
         
         SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");		
         
         // 更新设备
         int x=0;
         int y =0;
         String resultSB = GetCameraPreviewURL(pageNo,pageSize,2);

         JSONObject jsonStringSB = JSONObject.parseObject(resultSB);

         JSONObject jsonDataSB = jsonStringSB.getJSONObject("data");

         Integer jsonTotalSB = jsonDataSB.getInteger("total");   // 总条数

         System.out.println("设备总条数为----------" + jsonTotalSB +"----------------------");
         
         List<String> sbStr = new ArrayList<>();
         
         if(jsonTotalSB > 0) {
        	 
        	 Integer pageNum = jsonTotalSB / 1000+1;  // 判断循环几次

             for (int i = 1; i <= pageNum.intValue(); i++) {

                 String resultData = GetCameraPreviewURL(i,1000,2);

                 // 将String转化为json数据
                 JSONObject objData = JSONObject.parseObject(resultData);

                 JSONObject jsonObjData = objData.getJSONObject("data");

                 JSONArray arrayList = JSON.parseArray(jsonObjData.getString("list"));

                 Iterator<Object> it = arrayList.iterator();
                 while (it.hasNext()) {

                     JSONObject obj = (JSONObject) it.next();

                     KshHlhtSbxx bean = new KshHlhtSbxx();
                     
                     sbStr.add(obj.getString("gbIndexCode"));

                     if(mapSb.get(obj.getString("regionIndexCode"))==null){

                     }else{
                    	 
                         bean.setSbId(obj.getString("gbIndexCode"));
    
                         bean.setZzjgdm(obj.getString("regionIndexCode"));
                         
                         bean.setJkdmc(obj.getString("cameraName"));
                         
                         bean.setCjsj(df.parse(df.format(new Date())));

                         bean.setAzwwlx(obj.getString("installLocation"));

                         bean.setJkdbm(obj.getString("cameraIndexCode"));

                         KshHlhtSbxx sbxxInfo = kshHlhtSbxxService.queryBySbId(obj.getString("gbIndexCode"));

                         if(sbxxInfo == null) {
                        	 
                        	 // 先去temp临时表中查询leaf为true的库区名称
                        	 List<NodeTemp> tempList = kshHlhtZzjgService.queryKqmcByTrue(obj.getString("regionIndexCode"));
                        	 
                        	 for (NodeTemp nodeTemp : tempList) {
                        		 // 查询安防，仓内，业务的上级库区名称
                        		 if(nodeTemp.getName().equals("安防") || nodeTemp.getName().equals("仓内") || nodeTemp.getName().equals("业务")) {
                        			 TreeNode treeNode1 = kshHlhtZzjgService.queryById(nodeTemp.getFid());
                        			 if(treeNode1 != null) {
                        				 bean.setKqmc(treeNode1.getZzmc());
                        			 }   			 
                        		 }else {
                        			  bean.setKqmc(nodeTemp.getName());
                        		 }
							 } 
                        	 
                        	 bean.setYhid(obj.getString("gbIndexCode").substring(0, 2));

                             kshHlhtSbxxService.insertKshHlhtSbxx(bean);
                             
                             x++;
                             
                             System.out.println("--------------------新增设备信息 --------------");

                         }else{
                            	 
                            	 // 先去temp临时表中查询leaf为true的库区名称
                            	 List<NodeTemp> tempList = kshHlhtZzjgService.queryKqmcByTrue(obj.getString("regionIndexCode"));
                            	 
                            	 for (NodeTemp nodeTemp : tempList) {
                            		 // 查询安防，仓内，业务的上级库区名称
                            		 if(nodeTemp.getName().equals("安防") || nodeTemp.getName().equals("仓内") || nodeTemp.getName().equals("业务")) {
                            			 TreeNode treeNode1 = kshHlhtZzjgService.queryById(nodeTemp.getFid());
                            			 if(treeNode1 != null) {
                            				 sbxxInfo.setKqmc(treeNode1.getZzmc());
                            			 }   			 
                            		 }else {
                            			     sbxxInfo.setKqmc(nodeTemp.getName());
                            		 }
    							 }
                            	 
                            	 sbxxInfo.setJkdmc(obj.getString("cameraName"));                            	 
                            	 sbxxInfo.setZzjgdm(obj.getString("regionIndexCode"));                            	 
                            	 kshHlhtSbxxService.updateKshHlhtSbxx(sbxxInfo);
                            	 
                                 y++;
                                 System.out.println("--------------------更新设备信息-------------");
                         }
                     }
                 }
            }
         }
               
         // 删除不存在的设备信息
        List<String> sbInfoId = kshHlhtSbxxService.queryListStrSbId(zzjgId.substring(0, 2));
        		 
        List<String> newSbStr = new ArrayList<String>(sbStr);  // 海康设备信息Id
 		List<String> newSbInfoId = new ArrayList<String>(sbInfoId);	// 设备表中设备Id	
 		
 		newSbInfoId.removeAll(newSbStr);
 		
 		System.out.println("删除设备数：" + newSbInfoId.size());
 		
 		if(newSbInfoId.size() >0) {
 			kshHlhtSbxxService.deleteListStrBySbId(newSbInfoId);
 		}
 		     
	     KshInsertAndUpdate kshInsertAndUpdate = new KshInsertAndUpdate();
	     kshInsertAndUpdate.setInsertNum(x);
	     kshInsertAndUpdate.setUpdateNum(y);
	     kshInsertAndUpdate.setCreateTime(new SimpleDateFormat("yyyy-dd-MM HH:mm:ss").format(new Date()));
	     System.out.println("=============================设备更新完成====================================");
	     r.setData(kshInsertAndUpdate);
			
		}catch (Exception e) {
            log.error("手动同步异常", e);
            r.failure("手动同步异常");
            e.printStackTrace();
        }
        return r;
	}*/
	
	@ApiOperation(value = "手动同步(优化方法)", notes="手动同步(优化方法)")
    @RequestMapping(value = "/synchronizationHand", method = RequestMethod.POST)
    @ResponseBody
    public RootResult<Object> synchronizationHand(String zzjgId){
		RootResult<Object> r = new RootResult<Object>();
		try {
		
		kshHlhtZzjgService.deleteTemp();
		
		//更新组织机构
        Integer pageNo = 1;
        Integer pageSize = 1;
        Map<String,Object> map = new HashMap<>();
        Map<String,Object> mapSb = new HashMap<>();
        String result = GetCameraPreviewURL(pageNo,pageSize,1);

        JSONObject jsonString = JSONObject.parseObject(result);

        JSONObject jsonData = jsonString.getJSONObject("data");

        Integer jsonTotal = jsonData.getInteger("total");   // 总条数	
        
        System.out.println();
		
		if(jsonTotal > 0) {
        	
        	Integer pageNum = jsonTotal / 1000 + 1;  // 判断循环几次

            for (int i = 1; i <= pageNum.intValue(); i++) {

                String resultData = GetCameraPreviewURL(i, 1000, 1);

                // 将String转化为json数据
                JSONObject objData = JSONObject.parseObject(resultData);

                JSONObject jsonObjData = objData.getJSONObject("data");

                JSONArray arrayList = JSON.parseArray(jsonObjData.getString("list"));

                Iterator<Object> it = arrayList.iterator();
                while (it.hasNext()) {
                    JSONObject obj = (JSONObject) it.next();
                    NodeTemp nodeTemp = new NodeTemp(); 
                    if(obj.getString("parentIndexCode").equals("root000000")) {
                    	nodeTemp.setFid("120000");
                    }else {
                    	nodeTemp.setFid(obj.getString("parentIndexCode"));
                    }
                    if(obj.getString("indexCode").equals("root000000")) {
                    	nodeTemp.setZid("120000");
                    }else {
                    	nodeTemp.setZid(obj.getString("indexCode"));
                    } 
                    nodeTemp.setName(obj.getString("name"));
                    nodeTemp.setLeaf(obj.getString("leaf"));
                    kshHlhtZzjgService.saveTemp(nodeTemp);
                }
            }            	
        }
					
        if(jsonTotal > 0) {
        	 
        	 Integer pageNum = jsonTotal / 1000+1;  // 判断循环几次

             for (int i = 1; i <= pageNum.intValue(); i++) {

                 String resultData = GetCameraPreviewURL(i,1000,1);

                 // 将String转化为json数据
                 JSONObject objData = JSONObject.parseObject(resultData);

                 JSONObject jsonObjData = objData.getJSONObject("data");

                 JSONArray arrayList = JSON.parseArray(jsonObjData.getString("list"));

                 Iterator<Object> it = arrayList.iterator();
                 while (it.hasNext()) {

                     JSONObject obj = (JSONObject) it.next();

                     String name = obj.getString("name");

                     String parentId = obj.getString("parentIndexCode");  // 父节点

                     String indexCode = obj.getString("indexCode");
 
                	 TreeNode treeNode1 = this.kshHlhtZzjgService.queryById(obj.getString("indexCode"));
                     if (treeNode1 != null){	 
                       treeNode1.setZzmc(name);
                       this.kshHlhtZzjgService.updateKshHlhtScfz(treeNode1);
                       System.out.println("==================更新组织机构===================");
                     }else {
                    	List<NodeTemp> nodeTemp = kshHlhtZzjgService.queryListTemp(obj.getString("indexCode"));
              			KshHlhtScfzInVo invo = new KshHlhtScfzInVo();
              			for (NodeTemp node : nodeTemp) {
              				invo.setZzmc(node.getName());
              				invo.setZId(node.getZid());
              				invo.setFId(node.getFid());
              				kshHlhtZzjgService.insertClassZzjg(invo);
              				System.out.println("==================新增组织机构===================");
              		  }
                   }   
                }
             }
         }
         
         System.out.println("================================组织机构更新完成====================================");
         
         SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");		
         
         // 更新设备
         int x=0;
         int y =0;
         String resultSB = GetCameraPreviewURL(pageNo,pageSize,2);

         JSONObject jsonStringSB = JSONObject.parseObject(resultSB);

         JSONObject jsonDataSB = jsonStringSB.getJSONObject("data");

         Integer jsonTotalSB = jsonDataSB.getInteger("total");   // 总条数

         System.out.println("设备总条数为----------" + jsonTotalSB +"----------------------");
         
         List<String> sbStr = new ArrayList<>();
         
         if(jsonTotalSB > 0) {
        	 
        	 Integer pageNum = jsonTotalSB / 1000+1;  // 判断循环几次

             for (int i = 1; i <= pageNum.intValue(); i++) {

                 String resultData = GetCameraPreviewURL(i,1000,2);

                 // 将String转化为json数据
                 JSONObject objData = JSONObject.parseObject(resultData);

                 JSONObject jsonObjData = objData.getJSONObject("data");

                 JSONArray arrayList = JSON.parseArray(jsonObjData.getString("list"));

                 Iterator<Object> it = arrayList.iterator();
                 while (it.hasNext()) {

                     JSONObject obj = (JSONObject) it.next();

                     KshHlhtSbxx bean = new KshHlhtSbxx();
                     
                     sbStr.add(obj.getString("gbIndexCode"));
 
                     bean.setSbId(obj.getString("gbIndexCode"));

                     bean.setZzjgdm(obj.getString("regionIndexCode"));
                     
                     bean.setJkdmc(obj.getString("cameraName"));
                     
                     bean.setCjsj(df.parse(df.format(new Date())));

                     bean.setAzwwlx(obj.getString("installLocation"));

                     bean.setJkdbm(obj.getString("cameraIndexCode"));
                     String status = obj.getString("status");   // 在线状态
                     if(status != null) {
                         Integer stat = Integer.parseInt(status);

                         if(stat != null) {
                             if(Integer.parseInt(status) == 1) {   // 1-在线，2-离线      ----- >    0：在线；1离线
                                 bean.setSfzx(0);
                             }else if(Integer.parseInt(status) == 2){
                                 bean.setSfzx(1);
                             }
                         }
                     }else {
                         bean.setSfzx(0);
                     }

                     KshHlhtSbxx sbxxInfo = kshHlhtSbxxService.queryBySbId(obj.getString("gbIndexCode"));

                     if(sbxxInfo == null) {
                        	 
                    	 // 先去temp临时表中查询leaf为true的库区名称
                    	 List<NodeTemp> tempList = kshHlhtZzjgService.queryKqmcByTrue(obj.getString("regionIndexCode"));
                    	 
                    	 for (NodeTemp nodeTemp : tempList) {
                    		 // 查询安防，仓内，业务的上级库区名称
                    		 if(nodeTemp.getName().equals("安防") || nodeTemp.getName().equals("仓内") || nodeTemp.getName().equals("业务")) {
                    			 TreeNode treeNode1 = kshHlhtZzjgService.queryById(nodeTemp.getFid());
                    			 if(treeNode1 != null) {
                    				 bean.setKqmc(treeNode1.getZzmc());
                    			 }   			 
                    		 }else {
                    			  bean.setKqmc(nodeTemp.getName());
                    		 }
                             if (nodeTemp.getName().equals("仓内")) {
                                 bean.setSfcn("1");
                             } else if (nodeTemp.getName().equals("仓外")) {
                                 bean.setSfcn("2");
                             } else if (nodeTemp.getName().equals("安防")) {
                                 bean.setSfcn("5");
                             } else if (nodeTemp.getName().equals("业务")) {
                                 bean.setSfcn("6");
                             }
						 } 
                    	 
                    	 bean.setYhid(obj.getString("gbIndexCode").substring(0, 2));

                         kshHlhtSbxxService.insertKshHlhtSbxx(bean);
                         
                         x++;
                         
                         System.out.println("--------------------新增设备信息 --------------");

                      }else{
                            	 
                    	 // 先去temp临时表中查询leaf为true的库区名称
                    	 List<NodeTemp> tempList = kshHlhtZzjgService.queryKqmcByTrue(obj.getString("regionIndexCode"));
                    	 
                    	 for (NodeTemp nodeTemp : tempList) {
                    		 // 查询安防，仓内，业务的上级库区名称
                             if(nodeTemp.getName().equals("安防") || nodeTemp.getName().equals("仓内") || nodeTemp.getName().equals("仓外") || nodeTemp.getName().equals("业务")) {
                                 TreeNode treeNode1 = kshHlhtZzjgService.queryById(nodeTemp.getFid());
                                 if(treeNode1 != null) {
                                     bean.setKqmc(treeNode1.getZzmc());
                                 }
                             }else {
                                 bean.setKqmc(nodeTemp.getName());
                             }
                             if(nodeTemp.getName().equals("仓内")) {
                                 bean.setSfcn("1");
                             } else if(nodeTemp.getName().equals("仓外")) {
                                 bean.setSfcn("2");
                             } else if(nodeTemp.getName().equals("安防")) {
                                 bean.setSfcn("5");
                             } else if(nodeTemp.getName().equals("业务")) {
                                 bean.setSfcn("6");
                             }
                             System.out.println(bean.getSbId()+"====="+nodeTemp.getName());
						 }
                    	 
                    	 sbxxInfo.setJkdmc(obj.getString("cameraName"));                            	 
                    	 sbxxInfo.setZzjgdm(obj.getString("regionIndexCode"));
                         sbxxInfo.setSfzx(bean.getSfzx());
                    	 sbxxInfo.setJkdbm(obj.getString("cameraIndexCode"));
                    	 kshHlhtSbxxService.updateKshHlhtSbxx(sbxxInfo);
                    	 
                         y++;
                         System.out.println("--------------------更新设备信息-------------");
                      }
                 }
             }
         }
               
         // 删除不存在的设备信息
        /*List<String> sbInfoId = kshHlhtSbxxService.queryListStrSbId(zzjgId.substring(0, 2));
        		 
        List<String> newSbStr = new ArrayList<String>(sbStr);  // 海康设备信息Id
 		List<String> newSbInfoId = new ArrayList<String>(sbInfoId);	// 设备表中设备Id	
 		
 		newSbInfoId.removeAll(newSbStr);
 		
 		System.out.println("删除设备数：" + newSbInfoId.size());
 		
 		if(newSbInfoId.size() >0) {
 			kshHlhtSbxxService.deleteListStrBySbId(newSbInfoId);
 		}*/
 		     
	     KshInsertAndUpdate kshInsertAndUpdate = new KshInsertAndUpdate();
	     kshInsertAndUpdate.setInsertNum(x);
	     kshInsertAndUpdate.setUpdateNum(y);
	     kshInsertAndUpdate.setCreateTime(new SimpleDateFormat("yyyy-dd-MM HH:mm:ss").format(new Date()));
	     System.out.println("=============================设备更新完成====================================");
	     r.setData(kshInsertAndUpdate);
			
		}catch (Exception e) {
            log.error("手动同步异常", e);
            r.failure("手动同步异常");
            e.printStackTrace();
        }
        return r;
	}
	

    public String GetCameraPreviewURL(Integer pageNo,Integer pageSize,Integer type) {
        /**
         * STEP1：设置平台参数，根据实际情况,设置host appkey appsecret 三个参数.
         */
    	// 外网的 
        /*ArtemisConfig.host = "106.3.145.75:443"; // artemis网关服务器ip端口
        ArtemisConfig.appKey = "26469219"; // 秘钥appkey   
        ArtemisConfig.appSecret = "w4GKdMLvVTxDLUgtzV2L";*/// 秘钥appSecret   
        
    	
    	// 内网的
    	/*ArtemisConfig.host = "172.16.13.3:443"; // artemis网关服务器ip端口  
		ArtemisConfig.appKey = "26469219"; // 秘钥appkey     28116466
		ArtemisConfig.appSecret = "w4GKdMLvVTxDLUgtzV2L";// 秘钥appSecret     W9zihM0hNRsnNic3zuKM
*/    	
    	// 政务外网 
		/*ArtemisConfig.host = "192.168.7.101:443"; // artemis网关服务器ip端口  
		ArtemisConfig.appKey = "22129988"; // 秘钥appkey    28116466
		ArtemisConfig.appSecret = "vHvyP8OJV5uLoApXMaGS";// 秘钥appSecret   W9zihM0hNRsnNic3zuKM
*/    	
    	
    	ArtemisConfig.host = "10.69.3.1:443"; // artemis网关服务器ip端口  
		ArtemisConfig.appKey = "24012924"; // 秘钥appkey   28116466
		ArtemisConfig.appSecret = "uHzSYRUJpnCVCJSIEUWc";// 秘钥appSecret   W9zihM0hNRsnNic3zuKM
    	
        /**
         * STEP2：设置OpenAPI接口的上下文
         */
        final String ARTEMIS_PATH = "/artemis";

        String body = null;

        String contentType = null;

        Map path = new HashMap();

        if(type == 1) {   // 获取区域列表
            /**
             * STEP3：设置接口的URI地址
             */
            final String previewURLsApi = ARTEMIS_PATH +
                    "/api/irds/v2/region/nodesByParams";     // 获取区域列表
            path = new HashMap (2) {
                {
                    put("https://", previewURLsApi);//根据现场环境部署确认是http还是https
                }
            };

            /**
             * STEP4：设置参数提交方式
             */
            contentType = "application/json";

            /**
             * STEP5：组装请求参数
             */
            JSONObject jsonBody = new JSONObject();

            // 获取区域列表所要传的参数
            jsonBody.put("pageNo", pageNo);
            jsonBody.put("pageSize", pageSize);
            jsonBody.put("resourceType", "camera");
            jsonBody.put("cascadeFlag", 0);


            body = jsonBody.toJSONString();
        }else {

            /**
             * STEP3：设置接口的URI地址
             */
            final String previewURLsApi = ARTEMIS_PATH +
                    "/api/resource/v1/cameras";     // 获取分页监控点资源
            path = new HashMap (2) {
                {
                    put("https://", previewURLsApi);//根据现场环境部署确认是http还是https
                }
            };

            /**
             * STEP4：设置参数提交方式
             */
            contentType = "application/json";

            /**
             * STEP5：组装请求参数
             */
            JSONObject jsonBody = new JSONObject();

            // 获取分页监控点资源参数
            jsonBody.put("pageNo", pageNo);
            jsonBody.put("pageSize", pageSize);


            body = jsonBody.toJSONString();
        }


        /**
         * STEP6：调用接口
         */
        String result = ArtemisHttpUtil.doPostStringArtemis(path, body, null, null,contentType , null);// post请求application/json类型参数
        return result;
    }

}
