package com.jusfoun.ydylsz.service;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.jusfoun.ydylsz.mapper.CameraAreaMapper;
import com.jusfoun.ydylsz.vo.CameraAreas;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import java.util.stream.Collectors;

import static com.sun.org.apache.xerces.internal.impl.xpath.regex.CaseInsensitiveMap.get;

/**
 * @Classname CameraAreaService
 * @Description 摄像头区域
 * @Date 2023/12/14 15:46
 * @Created by rising123sun
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class CameraAreaService {
    @Autowired
    private KshHlhtSbxxService kshHlhtSbxxService;

    @Autowired
    private CameraAreaMapper cameraAreaMapper;

//    public JSONArray addCameraArea(String cookie) {
//        JSONArray root = kshHlhtSbxxService.getCameraPreviewStatusURLMenu("root000000", cookie);
//        JSONArray jsonArray = new JSONArray();
//        JSONArray result = getAllCameraArea(root, cookie, jsonArray);
//        for (Object o : result) {
//            // 循环遍历所有摄像头区域并插入到数据库
//            JSONObject jsonObject = (JSONObject) o;
//            CameraAreas cameraArea = new CameraAreas();
//            cameraArea.setId(jsonObject.getString("id"));
//            cameraArea.setText(jsonObject.getString("text"));
//            cameraArea.setLabel(jsonObject.getString("label"));
//            cameraArea.setPId(jsonObject.getString("pId"));
//            cameraArea.setCls(jsonObject.getString("cls"));
//            cameraArea.setLeaf(jsonObject.getBoolean("leaf"));
//            cameraArea.setIsDefault(jsonObject.getBoolean("isDefault"));
//            cameraArea.setIscascade(jsonObject.getString("iscascade"));
//            cameraArea.setIsParent(jsonObject.getBoolean("isParent"));
//            cameraArea.setState(jsonObject.getString("state"));
//            String orgCode = cameraAreaMapper.selectOrgCodeFormSys(jsonObject.getString("text"));
//            cameraAreaMapper.insertCameraArea(cameraArea);
//        }
//        return result;
//    }

    // 获取所有摄像头区域
    public JSONArray getAllCameraArea(JSONArray root, String cookie, JSONArray jsonArray) {
        if (root != null && root.size() > 0) {
            for (Object o : root) {
                jsonArray.add(o);
                JSONObject jsonObject = (JSONObject) o;
                String id = jsonObject.getString("id");
                JSONArray children = kshHlhtSbxxService.getCameraPreviewStatusURLMenu(id, cookie);
                if (children != null && children.size() > 0) {
                    jsonObject.put("children", children);
                    getAllCameraArea(children, cookie, jsonArray);
                }
            }
        }
        return jsonArray;
    }

    public JSONObject getCameraAreas(String orgCode) {
        JSONObject result = new JSONObject();
        List<CameraAreas> allCameraAreas = cameraAreaMapper.selectAllCameraAreas();
        List<CameraAreas> cameraAreas = new ArrayList<>();
        CameraAreas root = new CameraAreas();
        //  LS001 LS001021 LS001019 LS001020
        if ("LS001".equals(orgCode) || "LS001019".equals(orgCode) || "LS001020".equals(orgCode) || "LS001021".equals(orgCode)) {
            root = cameraAreaMapper.selectRootCameraArea(orgCode);
        } else {
            root = cameraAreaMapper.selectCurrentCameraArea(orgCode);
            if (root == null) {
                // 如果为空判断先判断是不是库区
                List<CameraAreas> kqList = cameraAreaMapper.selectKqCameraArea(orgCode);
                if (kqList.size() > 0) {
                    // 如果是库区
                    root = new CameraAreas();
                    root.setFid(0L);
                    root.setOrgCode(kqList.get(0).getRelateOrg());
                    root.setOrgName(kqList.get(0).getRelateOrgName());
                    root.setRelateOrg(kqList.get(0).getRelateOrg());
                    root.setRelateOrgName(kqList.get(0).getRelateOrgName());
                }
            }
        }
        if (root == null) {
            return result;
        }
        JSONObject rootJson = new JSONObject();
        rootJson.put("id", root.getFid());
        // LS001
        //LS001021
        //LS001019
        //LS001020 的数据text和label相同都为orgName
        if ("LS001".equals(orgCode) || "LS001019".equals(orgCode) || "LS001020".equals(orgCode) || "LS001021".equals(orgCode)) {
            if (root.getOrgName().contains("发改委")) {
                // 把发改委替换成空
                rootJson.put("text", root.getOrgName().replace("发改委", ""));
            } else {
                rootJson.put("text", root.getOrgName());
            }

        } else {
            if (root.getRelateOrgName().contains("发改委")) {
                // 把发改委替换成空
                rootJson.put("text", root.getRelateOrgName().replace("发改委", ""));
            } else {
                rootJson.put("text", root.getRelateOrgName());
            }
        }
        rootJson.put("label", root.getOrgName());
//        rootJson.put("pId", root.getOrgCode());
        rootJson.put("pCode", root.getOrgCode());
        rootJson.put("pName", root.getOrgName());
        rootJson.put("orgCode", root.getOrgCode());
        result.put("root", rootJson);
        // 根据orgCode过滤
        if (StringUtils.isNotBlank(orgCode)) {
            if ("LS001".equals(orgCode) || "LS001019".equals(orgCode) || "LS001020".equals(orgCode) || "LS001021".equals(orgCode)) {
                cameraAreas = cameraAreaMapper.selectRootCameraAreas();
            } else {
                cameraAreas = allCameraAreas.stream().filter(cameraArea -> StringUtils.isNotBlank(cameraArea.getOrgCode()) && cameraArea.getOrgCode().equals(orgCode)).collect(Collectors.toList());
            }
        } else {
            cameraAreas = cameraAreaMapper.selectRootCameraAreas();
        }

//        if (StringUtils.isNotBlank(orgCode) && !orgCode.equals("LS001") && !orgCode.equals("LS001019") && !orgCode.equals("LS001020") && !orgCode.equals("LS001021")) {
//        } else {
//            cameraAreas = cameraAreaMapper.selectAllCameraAreas();
//        }
        if (cameraAreas.size() <= 0) {
            rootJson.put("leaf", true);
        } else {
            rootJson.put("leaf", false);
        }
        if (cameraAreas.size() > 0) {

            JSONArray childrenArray = new JSONArray();
            // 将cameraAreas转换成JSONArray
            for (CameraAreas cameraArea : cameraAreas) {
                JSONObject jsonObject = new JSONObject();
                jsonObject.put("id", cameraArea.getFid());
                if (cameraArea.getRelateOrgName().contains("发改委")) {
                    // 把发改委替换成空
                    jsonObject.put("text", cameraArea.getRelateOrgName().replace("发改委", ""));
                } else {
                    jsonObject.put("text", cameraArea.getRelateOrgName());
                }
                jsonObject.put("label", cameraArea.getOrgName());
//                jsonObject.put("pId", cameraArea.getOrgCode());
                jsonObject.put("pCode", orgCode);
                jsonObject.put("pName", root.getOrgName());
                jsonObject.put("orgCode", cameraArea.getRelateOrg());
                // 判断是否还有子集,如果有子集则递归获取子集
                List<CameraAreas> children = allCameraAreas.stream().filter(cameraArea1 -> cameraArea1.getOrgCode().equals(cameraArea.getRelateOrg())).collect(Collectors.toList());
                if (children.size() > 0) {
                    jsonObject.put("leaf", false);
                    jsonObject.put("children", getChildren(cameraArea, allCameraAreas));
                } else {
                    jsonObject.put("leaf", true);
                    jsonObject.put("children", new JSONArray());
                }
                childrenArray.add(jsonObject);
            }
            rootJson.put("children", childrenArray);
        }

        return result;
    }


    private JSONArray getChildren(CameraAreas cameraArea, List<CameraAreas> allCameraAreas) {
        JSONArray result = new JSONArray();
        List<CameraAreas> children = allCameraAreas.stream().filter(cameraArea1 -> cameraArea1.getOrgCode().equals(cameraArea.getRelateOrg())).collect(Collectors.toList());
        for (CameraAreas child : children) {
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("id", child.getFid());
            if (child.getRelateOrgName().contains("发改委")) {
                // 把发改委替换成空
                jsonObject.put("text", child.getRelateOrgName().replace("发改委", ""));
            } else {
                jsonObject.put("text", child.getRelateOrgName());
            }
            jsonObject.put("label", child.getOrgName());
//            jsonObject.put("pId", child.getOrgCode());
            jsonObject.put("orgCode", child.getRelateOrg());
            jsonObject.put("pCode", cameraArea.getOrgCode());
            jsonObject.put("pName", cameraArea.getOrgName());
            // 判断是否还有子集,如果有子集则递归获取子集
            List<CameraAreas> children1 = allCameraAreas.stream().filter(cameraArea1 -> cameraArea1.getOrgCode().equals(child.getRelateOrg())).collect(Collectors.toList());
            if (children1.size() > 0) {
                jsonObject.put("leaf", false);
                jsonObject.put("children", getChildren(child, allCameraAreas));
            } else {
                jsonObject.put("leaf", true);
                jsonObject.put("children", new JSONArray());
            }
            result.add(jsonObject);
        }
        return result;
    }

    public List<String> getQyjdmcList(JSONObject cameraAreas) {
        List<String> result = new ArrayList<>();
        // 根结点
        if (cameraAreas != null) {
            JSONArray children = cameraAreas.getJSONArray("children");
            if (children != null && children.size() > 0) {
                result = getQyjdmc(children);
            } else {
                result.add(cameraAreas.getString("text"));
            }
        }
        return result;
    }

    public List<String> getQyjdmc(JSONArray children) {
        // 遍历children，判断leaf是否为true,如果为true则说明是叶子节点,否则继续递归，最后结果去重
        List<String> result = new ArrayList<>();
        if (children != null && children.size() > 0) {
            for (Object o : children) {
                JSONObject jsonObject = (JSONObject) o;
                Boolean leaf = jsonObject.getBoolean("leaf");
                if (leaf) {
                    result.add(jsonObject.getString("text"));
                } else {
                    JSONArray children1 = jsonObject.getJSONArray("children");
                    result.addAll(getQyjdmc(children1));
                }
            }
        }
        return result.stream().distinct().collect(Collectors.toList());
    }
}
