package com.jusfoun.ydylsz.util;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;


/**
 * @author ldq
 * 依赖jar： fastjson-1.2.7.jar
 */

public class DDUtilFastJson {
	
	/**
	 * 描述: getJSON重载：list--->JSONArray
	 * @param list list里面可以是 实体或者FASTJSON
	 * @return
	 */
	public static JSONArray getJSON(List<?> list){
		String jsonString = JSON.toJSONString(list);
		JSONArray parse = (JSONArray) JSON.parse(jsonString);
		return parse;
	}
	/**
	 * 描述: getJSON重载：map--->JSONObject
	 * @param map map里面可以是 实体或者FASTJSON
	 * @return JSONObject
	 */
	public static JSONObject getJSON(Map<?,?> map){
		String jsonString = JSON.toJSONString(map);
		JSONObject parse = (JSONObject) JSON.parse(jsonString);
		return parse;
	}
	/**
	 * 描述: getJSON重载：jsonString--->JSONArray
	 * @param jsonString
	 * @return
	 */
//	public static JSONArray getJSON(String jsonString){
//		String stringToJSONString = stringToJSONString(jsonString,false);
//		JSONArray parse = (JSONArray) JSON.parse(stringToJSONString);
//		return parse;
//	}
	/**
	 * 描述: getJSON重载：org.json.JSONObject--->JSONObject
	 * @param jsonString
	 * @return
	 */
	public static org.json.JSONObject getJSON(JSONObject json){
		return new org.json.JSONObject(json.toString());
	}
	/**
	 * 描述: getJSON重载：org.json.JSONArray--->JSONArray
	 * @param jsonString
	 * @return
	 */
	public static org.json.JSONArray getJSON(JSONArray json){
		return new org.json.JSONArray(json.toString());
	}
	/**
	 * 描述: getJSON重载：org.json.JSONObject--->JSONObject
	 * @param jsonString
	 * @return
	 */
	public static JSONObject getJSON(org.json.JSONObject json){
		return JSON.parseObject(json.toString());
	}
	/**
	 * 描述: getJSON重载：org.json.JSONObject--->JSONObject
	 * @param jsonString
	 * @return
	 */
	public static JSONArray getJSON(org.json.JSONArray json){
		return JSON.parseArray(json.toString());
	}
	
	public static <T> T getJSON(Object json,Class<T> c){
		if(json instanceof JSONObject){
			return (T) json;
		}
		if(json instanceof JSONArray){
			return (T) json;
		}
		if(json instanceof org.json.JSONObject){
			String valueOf = String.valueOf(json);
			JSONObject obj = JSON.parseObject(valueOf);
			return (T) obj;
		}
		if(json instanceof org.json.JSONArray){
			String valueOf = String.valueOf(json);
			JSONArray obj = JSON.parseArray(valueOf);
			return (T) obj;
		}
		if(json instanceof String){
			String stringToJSONString = stringToJSONString(json.toString(),false);
			if(c.getSuperclass() == JSON.class){
				Object parse = JSON.parse(stringToJSONString);
				return (T) parse;
			}
			if(c == org.json.JSONObject.class){
				org.json.JSONObject parse = new org.json.JSONObject(stringToJSONString);
				return (T) parse;
			}
			if(c == org.json.JSONArray.class){
				org.json.JSONArray parse = new org.json.JSONArray(stringToJSONString);
				return (T) parse; 
			}
			return null;
		}
		//如果是实体则放入集合
		if(json instanceof List<?>){
			return (T) getJSON((List)json);
		}
		if(json instanceof Map){
			return (T) getJSON((Map)json);
		}
		throw new RuntimeException("DDUtilFastJson-->getFASTJSON错误：没有匹配到可转换的JSON类型");
	}
	
	/**
	 * 描述: 可以把部分不太标准的json字符串 转换成标准格式,方便了我们写json字符串。
	 * 例如 : --简略格式--{id:1,name:丁鑫,age:18,sex:1} --标准格式-->{\"id\":\"1\",\"name\":\"丁鑫\",\"age\":\"18\",\"sex\":\"1\"}
	 * @param jsonString
	 * @param hasLine 是否添加\
	 * @return
	 */
	public static String stringToJSONString(String jsonString, boolean hasLine){
		String sign = hasLine ? "\\\"" : "\"";
		int n = hasLine ? 2 : 1;
			
		if(jsonString.contains(sign)){
			System.err.println("DDUtilFastJson-->stringToJSONString:JSON已包含字符串"+sign+"不用转换");
			return jsonString;
		}
		if(jsonString.contains("'")){
			jsonString = jsonString.replace("'", "");
			System.err.println("DDUtilFastJson-->stringToJSONString:去掉了'符号");
		}
		StringBuilder sb = new StringBuilder(jsonString);
		int count = 0;
		for (int i = 1; i < jsonString.length()-1; i++) {
			char charAt = jsonString.charAt(i);
//			System.out.println(charAt);
			char charAt1 = jsonString.charAt(i-1);
			char charAt2 = jsonString.charAt(i+1);
			if(charAt!='[' && charAt!=']' && charAt!='{' && charAt!='}' && charAt!=':' && charAt!=','){
				if(charAt1!='[' && charAt1!=']' && charAt1!='{' && charAt1!='}' && charAt1!=':' && charAt1!=','){
					if(charAt2=='[' || charAt2==']' || charAt2=='{' || charAt2=='}' || charAt2==':' || charAt2==','){
						sb.insert(i+count+1, sign);
						count += n;
					}
				}else {
					sb.insert(i+count, sign);
					count += n;
					if(charAt2=='[' || charAt2==']' || charAt2=='{' || charAt2=='}' || charAt2==':' || charAt2==','){
						if(charAt1=='[' || charAt1==']' || charAt1=='{' || charAt1!='}' || charAt1==':' || charAt1==','){
							sb.insert(i+count+1, sign);
							count += n;
						}
					}
				}
			}
		}
		return sb.toString();
	}
	
	public static void main(String[] args) {
		
//getJavaObject
//		Object o = getJavaObject(a, my.class);
//		System.out.println(o);
//getJSONArray
//		my my1 = new my("阿达","12");
//		my my2 = new my("阿飞","18");
//		ArrayList<Object> arrayList = new ArrayList<Object>();
//		arrayList.add(my1);
//		arrayList.add(my2);
//		JSONArray jsonArray = getJSONArray(arrayList);
//		System.out.println(jsonArray);
//getJSONArray		
//		JSONArray parse = (JSONArray) JSON.parse("[{\"age\":\"12\",\"name\":\"阿达\"},{\"age\":\"18\",\"name\":\"阿飞\"}]");
//		System.out.println(parse);
		
		
	}
	
	
}

class my{
	
	private String name;
	private String age;
	
	public my(String name, String age) {
		super();
		this.name = name;
		this.age = age;
	}
	public my() {
		super();
		// TODO Auto-generated constructor stub
	}
	public my(String name, String age, List<Map> family) {
		super();
		this.name = name;
		this.age = age;
	}
	@Override
	public String toString() {
		return "my [name=" + name + ", age=" + age + "]";
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getAge() {
		return age;
	}
	public void setAge(String age) {
		this.age = age;
	}
	
	public static List<Map<String, Object>> families;
	
	static {
		families = new ArrayList<Map<String, Object>>();
		
		my dx = new my("丁鑫", "18");
		my ff = new my("凤凤", "16");
		my dyf = new my("丁逸凡", "0");
		my yy = new my("丁富根", "99");
		my nn = new my("周立翠", "88");
		
		HashMap<String, Object> family = new HashMap<>();
		List<my> myFamily=new ArrayList<my>();
		myFamily.add(dx);
		myFamily.add(ff);
		myFamily.add(dyf);
		family.put("title", "myFamily");
		family.put("rs", myFamily);
		family.put("change", null);
		families.add(family);
		
		HashMap<String, Object> map2 = new HashMap<>();
		List<my> bigFamily=new ArrayList<my>();
		bigFamily.add(yy);
		bigFamily.add(nn);
		bigFamily.add(dx);
		bigFamily.add(ff);
		bigFamily.add(dyf);
		map2.put("title", "bigFamily");
		map2.put("rs", bigFamily);
		map2.put("change", null);
		families.add(map2);
	}
	
}
