package com.jusfoun.ydylsz.util;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import javax.servlet.http.HttpServletResponse;

import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.usermodel.HSSFRichTextString;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Font;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.web.multipart.MultipartFile;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;

/**
 * @author ldq
 * 功能描述：目前针对hiConsole项目做简单的数据导出功能。
 * 导出的 excle文件会默认在服务器：D盘的exportFile文件夹下。（D:\exportFile\）或者根据需要自行修改 
 * 必要赋值：使用前先给一些必要的公开成员变量赋值。
 * 非必要赋值：一些私有的成员变量可以通过set方法赋值，用来自定义表格的一些样式。
 * 依赖jar：
 * poi-3.10-FINAL-20140208.jar
 * poi-3.16-beta1.jar
 * poi-3.16-beta2.jar
 * poi-examples-3.10-FINAL-20140208.jar
 * poi-excelant-3.10-FINAL-20140208.jar
 * poi-ooxml-3.10-FINAL-20140208.jar
 * poi-ooxml-schemas-3.10-FINAL-20140208.jar
 * poi-scratchpad-3.10-FINAL-20140208.jar
 * 依赖 工具类
 * DDUtilFastJson
 */
public class DDUtilPOI {
	
	
	/**
	 * 必要：rs用来接收excle里的数据。它是一个java对象。多条数据可以封装进一个集合。
	 * 		例如：调用业务层 List<User> rs = userService.queryAllUser();
	 * 		本工具类会自动把rs转换成JSONArray
	 */
	private static Object rs=null;
	/**
	 * 	必要: title用来给excle表填充数据。
	 * 		   例如：姓名，年龄，生日。
	 * 		   则：title=new JSONArray("[[姓名,name],[年龄,age],[生日,birthday]]");
	 * 	注意：title的顺序，必须和数据库查出来的信息的顺序对应，name，age，birthday对应数据库字段.
	 */
	private static JSONArray title=null;
	/**
	 *  选择填写：数据库字段值在页面输出需要转换给changes赋值：
	 *  例如：excle表的第5列单元格        性别：true-->男  false-->女   第10列    审核状态：...........
	 *  则 changes=new JSONObject("{5:{true:男,false:女},10:{0:未审核,1:审核通过,2:审核未通过}}");
	 */
	private static JSONObject changes=null;
	/**
	 * 	建议填写: 工作表名(如果不填就是default)
	 */
	private static String sheetName;
	/**
	 * 	建议填写: 导出的文件名(如果没填会自动随机文件名)
	 */
	private static String fileName=null;
	
	/**
	 *  必须填写: 指定文件生成的服务器路径
	 */
	private static String uploadPath;

	/**
	 *  必须填写: 指定文件下载路径
	 */
	private static String downloadPath;
	private static JSONArray normalJSONData;
	
	//excle 文档对象
	private static HSSFWorkbook wb;
	//一页  工作表对象
	private static HSSFSheet sheet;
	//样式对象
	private static HSSFCellStyle style;
	//字体对象
	private static Font font;
	
	//创建  excel文档对象  并完成一些基本设置
	@SuppressWarnings("deprecation")
	private static void createExcelObjectAndSet(){
		//创建  excel文档对象
		wb = new HSSFWorkbook();
		//处理fileName，sheetName为空的情况
		if(sheetName==null || sheetName.equals("")){
			if(fileName!=null && !fileName.equals("")){
				sheetName=fileName;
			}else {
				sheetName="default";
			}
		}
		//创建一页  工作表对象  并命名
		sheet = wb.createSheet(sheetName);
		//HSSFDataFormat format= wb.createDataFormat();
		sheet.setColumnWidth((short)3, 20* 256);  
		sheet.setColumnWidth((short)4, 20* 256); 
		sheet.setDefaultRowHeight((short)300); 
		//样式1  
		style = wb.createCellStyle(); // 样式对象  
		style.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);// 垂直居中 
		style.setAlignment(HSSFCellStyle.ALIGN_CENTER);// 水平居中
		//设置标题字体格式  
		font = wb.createFont();     
		//设置字体样式   
		font.setFontHeightInPoints((short)20);   //设置字体大小  
		font.setFontName("Courier New");   //设置字体，是什么类型例如：宋体  
	}
	
    /**
	 * 标题样式
	 */
	public static HSSFCellStyle tableTitleStyle(HSSFWorkbook workbook) {
         HSSFFont font = workbook.createFont();
         font.setFontHeightInPoints((short) 13);
         //字体加粗
         font.setBoldweight(HSSFFont.BOLDWEIGHT_BOLD);
         //设置字体名字 
         font.setFontName("Courier New");
         //设置样式; 
         HSSFCellStyle style = workbook.createCellStyle();
         //在样式用应用设置的字体;  
         style.setFont(font);
         //设置自动换行; 
         style.setWrapText(false);
         //设置水平对齐的样式为居中对齐;  
         style.setAlignment(HSSFCellStyle.ALIGN_CENTER);
         //设置垂直对齐的样式为居中对齐; 
         style.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);
         style.setFont(font);
         return style;
	}
	
    /**
     * 列头单元格样式
     */
 /*   public static HSSFCellStyle getStyle(HSSFWorkbook workbook) {
    	// 设置字体
        HSSFFont font = workbook.createFont();
        //设置字体名字 
        font.setFontName("Courier New");
        //设置样式; 
        HSSFCellStyle style = workbook.createCellStyle();
        //在样式用应用设置的字体;  
        style.setFont(font);
        //设置自动换行; 
        style.setWrapText(false);
        //设置水平对齐的样式为居中对齐;  
        style.setAlignment(HSSFCellStyle.ALIGN_CENTER);
        //设置垂直对齐的样式为居中对齐; 
        style.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);
       
        return style;
    }*/
    
    /**
     * 列数据单元格样式
     */
    public static HSSFCellStyle getColumnTopStyle(HSSFWorkbook workbook) {
    	// 设置字体
        HSSFFont font = workbook.createFont();
        //设置字体大小
        font.setFontHeightInPoints((short)11);
        //字体加粗
        font.setBoldweight(HSSFFont.BOLDWEIGHT_BOLD);
        //设置字体名字 
        font.setFontName("Courier New");
        //设置样式; 
        HSSFCellStyle style = workbook.createCellStyle();
        //设置底边框; 
        //在样式用应用设置的字体;  
        style.setFont(font);
        //设置自动换行; 
        style.setWrapText(false);
        //设置水平对齐的样式为居中对齐;  
        style.setAlignment(HSSFCellStyle.ALIGN_CENTER);
        //设置垂直对齐的样式为居中对齐; 
        style.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);
        
        return style;
    }
	//开始构建表格
	private static void createFirstRow(){
        HSSFRow row0 = sheet.createRow(0);
        row0.setHeightInPoints(25);
       
        //声明列对象
        HSSFCell cell = null;

        //创建标题
        for(int i=0;i<title.size();i++){
            cell = row0.createCell(i);
            HSSFRichTextString hssfString = new HSSFRichTextString(title.getJSONArray(i).getString(0));
            cell.setCellValue(hssfString);
            cell.setCellStyle(tableTitleStyle(wb));
            cell.setCellStyle(getColumnTopStyle(wb));
        }
//        for (int i = 0; i < title.size(); i++) {
//        	JSONArray jsonArray = title.getJSONArray(i);
//        	row0.createCell((short)i).setCellValue(jsonArray.getString(0));
//		}
	}
	
	private static void createNormalTitle(){
		//待完善
        HSSFRow row0 = sheet.createRow(0);
        row0.setHeightInPoints(25);
			
        for (int i = 0; i < title.size(); i++) {
        	JSONArray jsonArray = title.getJSONArray(i);
        	row0.createCell((short)i).setCellValue(jsonArray.getString(1));
		}
	}
	
    //添加每行数据
	private static void addRow(){
		com.alibaba.fastjson.JSONArray array;
		try {
			array = DDUtilFastJson.getJSON(rs,com.alibaba.fastjson.JSONArray.class);
		} catch (Exception e) {
			e.printStackTrace();
			throw new RuntimeException("DDUtilPOI-->addRow错误:输入的数据源类型只能是实体或者JSON数组");
		}
		int x = 0;
		//遍历结果集 然后写入单元格
		for (int i = 0; i < array.size(); i++) {
			JSONObject object;
			try {
				object = array.getJSONObject(i);
			} catch (Exception e) {
				System.err.println("添加第"+i+"行数据时jsonObject类型转换异常");
				continue;
			}
			HSSFRow rowN = sheet.createRow(x+1);
			x++;
			for (int j = 0; j < title.size(); j++) {
				JSONArray jsonArray = title.getJSONArray(j);
				String String = jsonArray.getString(1);
				String value = object.getString(String);
				if(changes!=null){
					@SuppressWarnings("static-access")
					JSONObject change = changes.getJSONObject(String.valueOf(j+1));
					if(change!=null && change.getString(value)!=null && !change.getString(value).equals("")){
						value = change.getString(value);
					}
				}
				
	            HSSFCell cell = rowN.createCell(j);
	            cell.setCellValue(value);
//	            cell.setCellStyle(getStyle(wb));
//				rowN.createCell((short)j).setCellValue(value);
			}
		}
	}
	
	//用流写入文件
	private static String createFile(){
		File folder = new File(uploadPath);
		System.out.println((folder.exists() && folder.isDirectory()) ? true : folder.mkdirs());
        FileOutputStream fileOut = null;  
        String filePath = null;
        if(fileName==null || fileName.equals("")){
        	SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd-HHmmss");
        	String format = sdf.format(new Date());
			fileName=format+"-"+UUID.randomUUID();
		}
        filePath = uploadPath+fileName+".xls";
        String returnFileName = fileName+".xls";
        try{            
            fileOut = new FileOutputStream(filePath);  
            wb.write(fileOut);
            System.out.print("serverUpload OK "+filePath);  
        }catch(Exception e){  
            e.printStackTrace();  
            throw new RuntimeException("DDUtilPOI-->createFile错误:文件路径错误,输出流失败");
        }  
        finally{  
            if(fileOut != null){  
                try {  
                    fileOut.close();
                    return returnFileName;
                } catch (IOException e) {  
                    // TODO Auto-generated catch block  
                    e.printStackTrace();  
                }  
            }  
        }
		return returnFileName;
	}
	// 自适应宽度(中文支持)
	private static void setSizeColumn(HSSFSheet sheet) {
	    for (int columnNum = 0; columnNum <title.size(); columnNum++) {
	        int columnWidth = sheet.getColumnWidth(columnNum) / 256;
	        for (int rowNum = 0; rowNum < sheet.getLastRowNum(); rowNum++) {
	            HSSFRow currentRow;
	            //当前行未被使用过
	            if (sheet.getRow(rowNum) == null) {
	                currentRow = sheet.createRow(rowNum);
	            } else {
	                currentRow = sheet.getRow(rowNum);
	            }

	            if (currentRow.getCell(columnNum) != null) {
	                HSSFCell currentCell = currentRow.getCell(columnNum);
	                if (currentCell.getCellType() == HSSFCell.CELL_TYPE_STRING) {
	                    int length = currentCell.getStringCellValue().getBytes().length;
	                    if (columnWidth < length) {
	                        columnWidth = length;
	                    }
	                }
	            }
	        }
	        sheet.setColumnWidth(columnNum, columnWidth * 256);
	    }
	}
	
	//用响应流写入文件
	private static void createFileByreponse(HttpServletResponse res) throws IOException {
		setSizeColumn(sheet);
		res.setContentType("application/octet-stream; charset=UTF-8");
		res.setHeader("content-disposition", "attachment;filename=" + URLEncoder.encode(fileName, "UTF-8"));
		try {
			wb.write(res.getOutputStream());
			if(!CheckUtil.checkNotNull(fileName)) {
				fileName = "数据表.xls";
			}
			res.getOutputStream().flush();
		} catch (Exception e) {
			e.printStackTrace();
			throw new RuntimeException("DDUtilPOI-->createFile错误:文件路径错误,输出流失败");
		} finally {
			res.getOutputStream().close();
		}
	}
	//创建  excel文档对象  并完成一些基本设置
		@SuppressWarnings("deprecation")
		private static void createExcelAndSet(){
			//创建  excel文档对象
			wb = new HSSFWorkbook();
		}
		
		//创建  excel文档对象  并完成一些基本设置
		@SuppressWarnings("deprecation")
		private static void createSheetAndSet(){
			//处理fileName，sheetName为空的情况
			if(sheetName==null || sheetName.equals("")){
				if(fileName!=null && !fileName.equals("")){
					sheetName=fileName;
				}else {
					sheetName="default";
				}
			}
			//创建一页  工作表对象  并命名
			sheet = wb.createSheet(sheetName);
			//HSSFDataFormat format= wb.createDataFormat();
//			sheet.setColumnWidth((short)3, 20* 256);  
//			sheet.setColumnWidth((short)4, 20* 256); 
//			sheet.setDefaultRowHeight((short)300);  
			//样式1  
			style = wb.createCellStyle(); // 样式对象  
			style.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);// 垂直居中 
			style.setAlignment(HSSFCellStyle.ALIGN_CENTER);// 水平居中
			//设置标题字体格式  
			font = wb.createFont();     
			//设置字体样式   
			font.setFontHeightInPoints((short)20);   //设置字体大小  
			font.setFontName("Courier New");   //设置字体，是什么类型例如：宋体  
//			for (int i = 0; i < title.size(); i++) {
//				System.out.println("-------------------------------------"+i);
//				sheet.autoSizeColumn((short)i);
//			}
		}

//---------------------------------------------------------------------------------------------------------------	
	
	/**
	 * @描述: 导出最简单的excle文件
	 * @param rs 
	 * 必要：用来接收excle里的数据。它是一个java对象或者是一个org.json.JSONArray。多条数据可以封装进一个集合。
	 * 例如：调用业务层 List<User> rs = userService.queryAllUser();
	 * 或者：new JSONArray("[{\"id\":\"1\",\"name\":\"丁鑫\",\"age\":\"18\",\"sex\":\"1\"}]")
	 * 本工具类会自动把rs转换成JSONArray
	 * @param title 
	 * 必要:用来给excle表填充数据。
	 * 例如：姓名，年龄，生日。
	 * 则：title=new JSONArray("[[姓名,name],[年龄,age],[生日,birthday]]");
	 * 注意：title的顺序，必须和数据库查出来的信息的顺序对应，name，age，birthday对应数据库字段.
	 * @param changes
	 * 选择填写：数据库字段值在页面输出需要转换给changes赋值：
	 * 例如：excle表的第5列单元格        性别：true-->男  false-->女   第10列    审核状态：...........
	 * 则 changes=new JSONObject("{5:{true:男,false:女},10:{0:未审核,1:审核通过,2:审核未通过}}");
	 * @param sheetName 选择填写:工作表名(如果不填就是default)
	 * @param fileName 建议填写:导出的文件名(如果没填会自动随机文件名)
	 * @param path 选择填写:如果其他项目，请指定服务器路径,该工具会把excle表导出到该服务器路径下。
	 */
	public static String createEasyExcel(Object rs, org.json.JSONArray title, org.json.JSONObject changes, String sheetName, String fileName, String uploadPath, String downloadPath){
		com.alibaba.fastjson.JSONArray titleFastArray  = null;
		com.alibaba.fastjson.JSONArray rsFastArray  = null;
		com.alibaba.fastjson.JSONObject changefastObj = null;
		if(CheckUtil.checkNotNull(title)) {
			titleFastArray = DDUtilFastJson.getJSON(title,
					com.alibaba.fastjson.JSONArray.class);
		}
		if(CheckUtil.checkNotNull(changes)) {
			changefastObj = DDUtilFastJson.getJSON(changes,
					com.alibaba.fastjson.JSONObject.class);
		}
		if(CheckUtil.checkNotNull(rs)) {
			rsFastArray = DDUtilFastJson.getJSON(rs,
					com.alibaba.fastjson.JSONArray.class);
		}

		DDUtilPOI.rs = rsFastArray;
		DDUtilPOI.title = titleFastArray;
		DDUtilPOI.changes = changefastObj;
		DDUtilPOI.sheetName = sheetName;
		DDUtilPOI.fileName = fileName;
		DDUtilPOI.uploadPath = uploadPath;
		DDUtilPOI.downloadPath = downloadPath;
		DDUtilPOI.wb = null;
		DDUtilPOI.sheet = null;
		DDUtilPOI.style = null;
		DDUtilPOI.font = null;
		
		createExcelObjectAndSet();
		
		createFirstRow();
		
		if(CheckUtil.checkNotNull(rsFastArray)) {
			addRow();
		}
		
		return createFile();
		
	}
	

	/**
	 * 
	 * author:ldq
	 * date:2018年9月2日
	 * @param rs
	 * @param title
	 * @param changes
	 * @param sheetName
	 * @param fileName
	 * @param res
	 * @throws IOException
	 * description:文件导出 不生成文件，直接到响应流，启动浏览器下载
	 */
	public static void createEasyExcelByResponse(Object rs, org.json.JSONArray title, org.json.JSONObject changes, String sheetName, String fileName,HttpServletResponse res) throws IOException{
		com.alibaba.fastjson.JSONArray titleFastArray  = null;
		com.alibaba.fastjson.JSONArray rsFastArray  = null;
		com.alibaba.fastjson.JSONObject changefastObj = null;
		if(CheckUtil.checkNotNull(title)) {
			titleFastArray = DDUtilFastJson.getJSON(title,
					com.alibaba.fastjson.JSONArray.class);
		}
		if(CheckUtil.checkNotNull(changes)) {
			changefastObj = DDUtilFastJson.getJSON(changes,
					com.alibaba.fastjson.JSONObject.class);
		}
		if(CheckUtil.checkNotNull(rs)) {
			rsFastArray = DDUtilFastJson.getJSON(rs,
					com.alibaba.fastjson.JSONArray.class);
		}

		DDUtilPOI.rs = rsFastArray;
		DDUtilPOI.title = titleFastArray;
		DDUtilPOI.changes = changefastObj;
		DDUtilPOI.sheetName = sheetName;
		DDUtilPOI.fileName = fileName;
		DDUtilPOI.wb = null;
		DDUtilPOI.sheet = null;
		DDUtilPOI.style = null;
		DDUtilPOI.font = null;
		createExcelObjectAndSet();
		createFirstRow();
		if(CheckUtil.checkNotNull(rsFastArray)) {
			addRow();
		}
		createFileByreponse(res);
	}
	
	public static String createMultiSheetExcel(Object rs, String fileName, String path){
		
		createExcelAndSet();
		
		com.alibaba.fastjson.JSONArray array;
		try {
			array = DDUtilFastJson.getJSON(rs,com.alibaba.fastjson.JSONArray.class);
		} catch (Exception e) {
			e.printStackTrace();
			throw new RuntimeException("DDUtilPOI-->addRow错误:输入的数据源类型只能是实体或者JSON数组");
		}
		for (int i = 0; i < array.size(); i++) {
			JSONObject obj = array.getJSONObject(i);
			String sheetName  = obj.getString("sheetName");
			System.out.println(sheetName);
			DDUtilPOI.sheetName = sheetName;
			createSheetAndSet();
			DDUtilPOI.title = obj.getJSONArray("title");
			createFirstRow();			
			DDUtilPOI.changes = obj.getJSONObject("changes");
			DDUtilPOI.rs = obj.getJSONArray("rs");
			addRow();
		}
		
		DDUtilPOI.fileName = fileName;
		DDUtilPOI.uploadPath = path;
		
		createFile();
		
		DDUtilPOI.wb = null;
		DDUtilPOI.sheet = null;
		DDUtilPOI.style = null;
		DDUtilPOI.font = null;
		
		return path;
	}
	
	public static void createMultiSheetExcelByResponse(Object rs, String fileName,HttpServletResponse response) throws IOException{
		
		createExcelAndSet();
		
		com.alibaba.fastjson.JSONArray array;
		try {
			array = DDUtilFastJson.getJSON(rs,com.alibaba.fastjson.JSONArray.class);
		} catch (Exception e) {
			e.printStackTrace();
			throw new RuntimeException("DDUtilPOI-->addRow错误:输入的数据源类型只能是实体或者JSON数组");
		}
		for (int i = 0; i < array.size(); i++) {
			JSONObject obj = array.getJSONObject(i);
			String sheetName  = obj.getString("sheetName");
			System.out.println(sheetName);
			DDUtilPOI.sheetName = sheetName;
			createSheetAndSet();
			DDUtilPOI.title = obj.getJSONArray("title");
			createFirstRow();			
			DDUtilPOI.changes = obj.getJSONObject("changes");
			DDUtilPOI.rs = obj.getJSONArray("rs");
			addRow();
		}
		
		DDUtilPOI.fileName = fileName;
//		DDUtilPOI.uploadPath = path;
		createFileByreponse(response);
		DDUtilPOI.wb = null;
		DDUtilPOI.sheet = null;
		DDUtilPOI.style = null;
		DDUtilPOI.font = null;
	}
	
	/**
	 * @描述: （待完善）导出中等复杂度级别的excle文件
	 * @param rs
	 * 必要：用来接收excle里的数据。它是一个java对象或者是一个org.json.JSONArray。多条数据可以封装进一个集合。
	 * 例如：调用业务层 List<User> rs = userService.queryAllUser();
	 * 或者：new JSONArray("[{\"id\":\"1\",\"name\":\"丁鑫\",\"age\":\"18\",\"sex\":\"1\"}]")
	 * 本工具类会自动把rs转换成JSONArray
	 * @param title 
	 * 必要:用来给excle表填充数据。
	 * 例如：姓名，年龄，生日。
	 * 则：title=new JSONArray("[[姓名,name],[年龄,age],[生日,birthday]]");
	 * 注意：title的顺序，必须和数据库查出来的信息的顺序对应，name，age，birthday对应数据库字段.
	 * @param changes
	 * 选择填写：数据库字段值在页面输出需要转换给changes赋值：
	 * 例如：excle表的第5列单元格        性别：true-->男  false-->女   第10列    审核状态：...........
	 * 则 changes=new JSONObject("{5:{true:男,false:女},10:{0:未审核,1:审核通过,2:审核未通过}}");
	 * @param fileName 建议填写:导出的文件名(如果没填会自动随机文件名)
	 * @param path 选择填写:如果其他项目，请指定服务器路径,该工具会把excle表导出到该服务器路径下。
	 * @param sheetName 选择填写:工作表名(如果不填就是default)
	 */
	public static String createNormalExcel(Object normalJSONData, String sheetName, String fileName, String path){
		
		DDUtilPOI.normalJSONData = DDUtilFastJson.getJSON(normalJSONData,com.alibaba.fastjson.JSONArray.class);
		System.out.println(normalJSONData);
		
		DDUtilPOI.rs = rs;
		DDUtilPOI.title = title;
		DDUtilPOI.changes = changes;
		DDUtilPOI.sheetName = sheetName;
		DDUtilPOI.fileName = fileName;
		DDUtilPOI.uploadPath = path;
		DDUtilPOI.wb = null;
		DDUtilPOI.sheet = null;
		DDUtilPOI.style = null;
		DDUtilPOI.font = null;
		
		createExcelObjectAndSet();
		
		for (int i = 0; i < DDUtilPOI.normalJSONData.size(); i++) {
			createNormalTitle();
		}
		
		addRow();
		
		return createFile();
		
	}
	
	/**
	 * 描述: 读取xls文件内容
	 * 例如: List<Map<String, String>> readXls = DDUtilPOI2.readXls("C:\\exportFile\\成功报告.xls", new Integer[]{1,2});
	 * @param filePath 文件路径
	 * @param arr 读取哪些列
	 * @return 
	 * @throws IOException
	 */
	public static List<Map<String, String>> readXls(String filePath, Integer[] arr) throws IOException {
		// InputStream is = new FileInputStream("d:\\student.xls");
		List<Map<String, String>> list = new ArrayList<Map<String, String>>();
		File file = new File(filePath);
		FileInputStream fileInputStream = new FileInputStream(file);
		String suffix = filePath.substring(filePath.length() - 4, filePath.length());
		Workbook firmUser = null;
		if (suffix.equals(".xls")) {
			firmUser = new HSSFWorkbook(fileInputStream);
		} else if (suffix.equals("xlsx")) {
			firmUser = new XSSFWorkbook(fileInputStream);
		}
		Sheet sheet = firmUser.getSheetAt(0);
		int lastRowNum = sheet.getLastRowNum();
		// 遍历行
		for (int r = 0; r <= lastRowNum; r++) {
			Row row = sheet.getRow(r);
			if (row == null) {
				continue;
			}

			Map map = new HashMap<String,String>();
			for (int i = 0; i < arr.length; i++) {
				// 循环列的值
				// 0、企业全称 1、企业简称 2、所在地（省/市） 4、所在地（市/区） 5、所在地（详细地址） 6、企业简介 7、企业规模
				// 8、企业行业（性质） 9、联系人
				// 10、联系人性别（0男/1女） 11、 联系人邮箱 12、企业logo
				if (row.getCell(arr[i]-1) != null) {
					Cell cell = row.getCell(arr[i]-1);
					int cellType = cell.getCellType();
					if (cellType == cell.CELL_TYPE_NUMERIC) {
						double num = cell.getNumericCellValue();
						if (num == (int) num) {
							map.put(arr[i]+"", (int) num + "");
						} else {
							map.put(arr[i]+"", num + "");
						}
					}
					if (cellType == cell.CELL_TYPE_STRING) {
						String str = cell.getStringCellValue();
						map.put(arr[i], str);
					}
				}
			}

			list.add(map);
		}
		return list;
	}
	
	/**
	 * 描述: 读取xls文件内容
	 * 例如: List<Map<String, String>> readXls = DDUtilPOI2.readXls("C:\\exportFile\\成功报告.xls", new Integer[]{1,2});
	 * @param filePath 文件路径
	 * @param arr 读取哪些列
	 * @return 
	 * @throws IOException
	 */
	public static List<Map<String, String>> readXlsFileInputStream(MultipartFile file, Integer[] arr) throws IOException {
		// 获取文件名
		String oriName = file.getOriginalFilename();
		// 获取文件后缀名
		String suffix = oriName.substring(oriName.lastIndexOf("."));
		InputStream fileInputStream = null;
		if(file==null){
			System.out.println("传入Excel出错");
		}
		fileInputStream = file.getInputStream();
		List<Map<String, String>> list = new ArrayList<Map<String, String>>();
		Workbook firmUser = null;
		if (suffix.equals(".xls")) {
			firmUser = new HSSFWorkbook(fileInputStream);
		} else if (suffix.equals(".xlsx")) {
			firmUser = new XSSFWorkbook(fileInputStream);
		}
		Sheet sheet = firmUser.getSheetAt(0);
		int lastRowNum = sheet.getLastRowNum();
		// 遍历行
		for (int r = 0; r <= lastRowNum; r++) {
			Row row = sheet.getRow(r);
			if (row == null) {
				continue;
			}

			Map map = new HashMap<String,String>();
			for (int i = 0; i < arr.length; i++) {
				// 循环列的值
				// 0、企业全称 1、企业简称 2、所在地（省/市） 4、所在地（市/区） 5、所在地（详细地址） 6、企业简介 7、企业规模
				// 8、企业行业（性质） 9、联系人
				// 10、联系人性别（0男/1女） 11、 联系人邮箱 12、企业logo
				if (row.getCell(arr[i]-1) != null) {
					Cell cell = row.getCell(arr[i]-1);
					if(cell.getCellType() == Cell.CELL_TYPE_NUMERIC){
						  cell.setCellType(Cell.CELL_TYPE_STRING);
					}
					int cellType = cell.getCellType();
					if (cellType == cell.CELL_TYPE_NUMERIC) {
						double num = cell.getNumericCellValue();
						if (num == (int) num) {
							map.put(arr[i]+"", (int) num + "");
						} else {
							map.put(arr[i]+"", num + "");
						}
					}
					if (cellType == cell.CELL_TYPE_STRING) {
						String str = cell.getStringCellValue();
						map.put(arr[i], str);
					}
				}
			}

			list.add(map);
		}
		return list;
	}
	/**
	 * 描述: 读取excel中的某一个单元格
	 * 例如: String desc = DDUtilPOI2.getDesc("C:\\exportFile\\成功报告.xls", 8, 1);
	 * @param path 服务器文件路径
	 * @param row 第几行
	 * @param column 第几列
	 * @return
	 * @throws IOException
	 */
	public static String readCell(String path,int row,int column) throws IOException{
		List<Map<String, String>> readXls = DDUtilPOI.readXls(path, new Integer[]{column});
		Map<String, String> map = readXls.get(row-1);
		return map.get(column-1);
	}
	
	public static void main(String[] args) throws InterruptedException, IOException {
//------------案例：创建简单excle-----------		
//		org.json.JSONArray rs = new org.json.JSONArray("[{\"id\":\"1\",\"name\":\"丁鑫\",\"age\":\"18\",\"sex\":\"1\"},{\"id\":\"3\",\"name\":\"小米粒\",\"age\":\"0\",\"sex\":\"0\"},{\"id\":\"2\",\"name\":\"凤凤\",\"age\":\"16\",\"sex\":\"0\"}]");
//		org.json.JSONArray title = new org.json.JSONArray("[[id,序号],[name,姓名],[age,年龄],[sex,性别]]");
//		org.json.JSONObject changes = new org.json.JSONObject("{4:{1:男,0:女}}");
//		String createEasyExcel = DDUtilPOI2.createEasyExcel( DDUtilFastJson.getJSON(rs), DDUtilFastJson.getJSON(title), DDUtilFastJson.getJSON(changes), "测试文档1", "测试文档", System.getProperty("user.dir")+"\\POI\\");
//------------案例：读取“C:\\exportFile\\”路径下的文件“成功报告.xls”的第8行第1列单元格.----------------------------------
//		String desc = DDUtilPOI2.readCell(System.getProperty("user.dir")+"\\POI\\"+"测试文档.xls", 1, 2);
//		System.out.println(desc);
//------------案例：读取“C:\\exportFile\\”路径下的文件“成功报告.xls”获得List<Map<String, String>>并把List中的第一个map中key为0的元素输出到控制台-----------
//		List<Map<String, String>> readXls = DDUtilPOI2.readXls(System.getProperty("user.dir")+"\\POI\\"+"测试文档.xls", new Integer[]{1,3,4});
//		System.out.println(readXls.get(1));
//------------案例：(待完善)创建普通难度excle-----------	
//------------案例：读取“C:\\exportFile\\”路径下的文件“成功报告.xls”的第8行第1列单元格.----------------------------------
		
		
//		org.json.JSONArray rs = new org.json.JSONArray("[{\"id\":\"1\",\"name\":\"丁鑫\",\"age\":\"18\",\"sex\":\"1\"},{\"id\":\"3\",\"name\":\"小米粒\",\"age\":\"0\",\"sex\":\"0\"},{\"id\":\"2\",\"name\":\"凤凤\",\"age\":\"16\",\"sex\":\"0\"}]");
//		org.json.JSONArray title = new org.json.JSONArray("[[id,序号],[name,姓名],[age,年龄],[sex,性别]]");
//		System.out.println(title);
		
		
//		String createEasyExcel1 = DDUtilPOI2.createNormalExcel( rs, title, changes, "测试文档1", "测试文档", "C:\\exportFile\\\\");

	}
	
}




	
	







