package com.jusfoun.ydylsz.util;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.OutputStream;

import org.apache.poi.util.IOUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * file输入输出工具类
 * @author lxy
 *
 */
public class FileUtil {
	
	private static Logger log = LoggerFactory.getLogger(FileUtil.class);
	
	/**
	 * 读取指定路径文本文件
	 * @param filePath
	 * @return
	 */
	public static String readText(String filePath) {
		StringBuilder str = new StringBuilder();
		BufferedReader in = null;
		try {
			in = new BufferedReader(new FileReader(filePath));
			String s;
			try {
				while ((s = in.readLine()) != null)
					str.append(s + '\n');
			} finally {
				in.close();
			}
		} catch (IOException e) {
			log.error("方法read异常", e);
			e.printStackTrace();
		}
		return str.toString();
	}

	/**
	 * 写出到指定路径文本文件
	 * @param dirPath 目录名
	 * @param fileName 文件名
	 * @param append 为true表示追加，false表示重头开始写
	 * @param text 要写入的文本字符串，text为null时直接返回
	 */
	public static void writeText(String dirPath, String fileName, boolean append, String text) {
		if (text == null){
			return;
		}
		File dir = new File(dirPath);
		if (!dir.exists()) {//文件不存在则创建
			dir.mkdirs();
		}
		try {
			BufferedWriter out = new BufferedWriter(new FileWriter(dirPath + fileName, append));
			try {
				out.write(text);
			} finally {
				out.close();
			}
		} catch (IOException e) {
			log.error("方法write异常", e);
			e.printStackTrace();
		}
	}
	
	/**
	 * @param dirPath 目录
	 * @param fileName 文件名
	 * @param bs
	 */
	public static void writeFile(String dirPath, String fileName, byte[] bs) {
		if (bs == null){
			return;
		}
		File dir = new File(dirPath);
		if (!dir.exists()) {//文件不存在则创建
			dir.mkdirs();
		}
		try {
			writeByteArrayToFile(new File(dirPath + fileName), bs);
		} catch (IOException e) {
			log.error("方法write异常", e);
			e.printStackTrace();
		}
	}
	
	
	public static void writeByteArrayToFile(File file, byte[] data) throws IOException {  

        OutputStream out = null;  

        try {  

            out =new FileOutputStream(file);  

            out.write(data);  

        } finally {  

            IOUtils.closeQuietly(out);  

        }  

    } 
}
