package com.jusfoun.ydylsz.util;

import java.awt.Graphics;
import java.awt.Image;
import java.awt.Rectangle;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Iterator;

import javax.imageio.ImageIO;
import javax.imageio.ImageReadParam;
import javax.imageio.ImageReader;
import javax.imageio.stream.ImageInputStream;


/**
 * 图片工具类
 * @author lxy
 */
public class ImgUtil {
	
	/**
	 * 传入宽度和长度，是否等比例缩放图片
	 * @param inputFile 源文件
	 * @param outFile 生成文件
	 * @param width 指定宽度
	 * @param height 指定高度
	 * @param format 格式
	 * @param auto 是否等比例操作
	 */
	public static void compressPic(String inputFile, String outFile,
			int width, int height, String format, boolean auto) {
		try {
			File file = new File(inputFile);
			BufferedImage bufferedImage = ImageIO.read(file);
			if (auto) {
				// 为等比缩放计算输出的图片宽度及高度
				double rate1 = ((double) bufferedImage.getWidth(null))
						/ (double) width + 0.1;
				double rate2 = ((double) bufferedImage.getHeight(null))
						/ (double) height + 0.1;
				// 根据缩放比率大的进行缩放控制
				double rate = rate1 > rate2 ? rate1 : rate2;
				width = (int) (((double) bufferedImage.getWidth(null)) / rate);
				height = (int) (((double) bufferedImage.getHeight(null)) / rate);
			}

			Image image = bufferedImage.getScaledInstance(width, height,
					Image.SCALE_DEFAULT);
			BufferedImage outputImage = new BufferedImage(width, height,
					BufferedImage.TYPE_INT_RGB);
			Graphics graphics = outputImage.getGraphics();
			graphics.drawImage(image, 0, 0, null);
			graphics.dispose();
			ImageIO.write(outputImage, format, new File(outFile));
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	/***
	 * 按指定的比例缩放图片
	 * @param inputFile 源文件
	 * @param outFile 生成文件
	 * @param scale 缩放比例，如1.2
	 */
	public static void scaleImage(String inputFile, String outFile,
			double scale, String format) {
		File file = new File(inputFile);
		BufferedImage bufferedImage;
		try {
			bufferedImage = ImageIO.read(file);
			int width = bufferedImage.getWidth();
			int height = bufferedImage.getHeight();
			width = getRoundIntFromDouble(width * scale);
			height = getRoundIntFromDouble(height * scale);
			Image image = bufferedImage.getScaledInstance(width, height,
					Image.SCALE_SMOOTH);
			BufferedImage outputImage = new BufferedImage(width, height,
					BufferedImage.TYPE_INT_RGB);
			Graphics graphics = outputImage.getGraphics();
			graphics.drawImage(image, 0, 0, null);
			graphics.dispose();
			ImageIO.write(outputImage, format, new File(outFile));
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	/**
	 * 裁剪图片
	 * @param srcFile源文件
	 * @param outFile输出文件
	 * @param x坐标
	 * @param y坐标
	 * @param width宽度
	 * @param height高度
	 * @return
	 */
	public static boolean cutPic(String srcFile, String outFile, int x, int y, int width, int height) {
		FileInputStream is = null;
		ImageInputStream iis = null;
		try {
			// 如果源图片不存在
			if (!new File(srcFile).exists()) {
				return false;
			}
			// 读取图片文件
			is = new FileInputStream(srcFile);
			// 获取文件格式
			String ext = srcFile.substring(srcFile.lastIndexOf(".") + 1);
			// ImageReader声称能够解码指定格式
			Iterator<ImageReader> it = ImageIO.getImageReadersByFormatName(ext);
			ImageReader reader = it.next();
			// 获取图片流
			iis = ImageIO.createImageInputStream(is);
			// 输入源中的图像将只按顺序读取
			reader.setInput(iis, true);
			// 描述如何对流进行解码
			ImageReadParam param = reader.getDefaultReadParam();
			// 图片裁剪区域
			Rectangle rect = new Rectangle(x, y, width, height);
			// 提供一个 BufferedImage，将其用作解码像素数据的目标
			param.setSourceRegion(rect);
			// 使用所提供的 ImageReadParam 读取通过索引 imageIndex 指定的对象
			BufferedImage bi = reader.read(0, param);
			// 保存新图片
			File tempOutFile = new File(outFile);
			if (!tempOutFile.exists()) {
				tempOutFile.mkdirs();
			}
			ImageIO.write(bi, ext, new File(outFile));
			return true;
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		} finally {
			try {
				if (is != null) {
					is.close();
				}
				if (iis != null) {
					iis.close();
				}
			} catch (IOException e) {
				e.printStackTrace();
				return false;
			}
		}
	}
	
	/**
	 * 将浮点型数据保留整数位转换成int型
	 * @param doubleValue
	 * @return
	 */
	public static Integer getRoundIntFromDouble(Double doubleValue) {
		return Integer.parseInt(String.valueOf(Math.round(doubleValue)));
	}
	
}
