//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by FernFlower decompiler)
//

package com.jusfoun.ydylsz.vo;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.commons.lang.StringUtils;
import org.springframework.validation.ObjectError;

public class ResponseWrapper {
    private StatusEnum status;
    private Integer infoCode;
    private String msg;
    private Object data;

    private ResponseWrapper() {
    }

    private ResponseWrapper(StatusEnum status, Integer infoCode, String msg, Object data) {
        this.msg = msg;
        this.status = status;
        this.infoCode = infoCode;
        this.data = data;
    }

    public static ResponseWrapper success(Integer infoCode, String info, Object data) {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.SUCCESS, infoCode, info, data);
    }

    public static ResponseWrapper success(Object data) {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.SUCCESS, 200, "操作成功", data);
    }

    public static ResponseWrapper success(String info) {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.SUCCESS, 200, info, "");
    }

    public static ResponseWrapper success() {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.SUCCESS, 200, "操作成功", "");
    }

    public static ResponseWrapper error(Integer infoCode, String info, Object data) {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.ERROR, infoCode, info, data);
    }

    public static ResponseWrapper error(String info) {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.ERROR, 500, info, "");
    }

    public static ResponseWrapper error() {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.ERROR, 500, "网络故障,请稍后重试", "");
    }

    public StatusEnum getStatus() {
        return this.status;
    }

    public void setStatus(StatusEnum status) {
        this.status = status;
    }

    public Integer getInfoCode() {
        return this.infoCode;
    }

    public void setInfoCode(Integer infoCode) {
        this.infoCode = infoCode;
    }

    public String getMsg() {
        return this.msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    public Object getData() {
        return this.data;
    }

    public void setData(Object data) {
        this.data = data;
    }

    public static ResponseWrapper validateFail(List<ObjectError> errorList) {
        List<String> list = new ArrayList();
        Iterator var2 = errorList.iterator();

        while(var2.hasNext()) {
            ObjectError objectError = (ObjectError)var2.next();
            list.add(objectError.getDefaultMessage());
        }

        return new ResponseWrapper(ResponseWrapper.StatusEnum.ERROR, 412, StringUtils.join(list, "<br/>"), "");
    }

    public static ResponseWrapper validateFail(List<ObjectError> errorList, String separate) {
        List<String> list = new ArrayList();
        Iterator var3 = errorList.iterator();

        while(var3.hasNext()) {
            ObjectError objectError = (ObjectError)var3.next();
            list.add(objectError.getDefaultMessage());
        }

        return new ResponseWrapper(ResponseWrapper.StatusEnum.ERROR, 412, StringUtils.join(list, separate), "");
    }

    public static ResponseWrapper choose(int num) {
        return num > 0 ? success(200, "操作成功", (Object)null) : fail();
    }

    public static ResponseWrapper invalid() {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.ERROR, 400, "数据不完整或格式错误", "");
    }

    public static ResponseWrapper deny() {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.ERROR, 403, "当前数据不可操作", "");
    }

    public static ResponseWrapper duplicate() {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.ERROR, 405, "已经存在唯一数据", "");
    }

    public static ResponseWrapper notFound() {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.ERROR, 404, "找不到记录,可能已被删除", "");
    }

    public static ResponseWrapper fail() {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.ERROR, 404, "操作不成功,可能是网络故障,请稍后重试", "");
    }

    public static ResponseWrapper fail(String msg) {
        return new ResponseWrapper(ResponseWrapper.StatusEnum.ERROR, 404, msg, "");
    }

    public boolean isSuccess() {
        return this != null && this.infoCode == 200;
    }

    public static enum StatusEnum {
        SUCCESS,
        ERROR;

        private StatusEnum() {
        }
    }
}
